{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "fastqc",
                "--outdir",
                "."
            ],
            "inputs": [
                {
                    "id": "#FastQC-v0.11.7.cwl/n_threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--threads"
                    },
                    "label": "Number of threads",
                    "doc": "Specifies the number of files which can be processed simultaneously. Each thread will be allocated 250MB of memory so you shouldn't run more threads than your available memory will cope with, and not more than 6 threads on a 32 bit machine.\n"
                },
                {
                    "id": "#FastQC-v0.11.7.cwl/in_fastq",
                    "format": "http://edamontology.org/format_1930",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "Input FASTQ file(s)",
                    "doc": "Input FASTQ file(s). If multiple files are provided then use space separated\n"
                }
            ],
            "doc": "FastQC reads a set of sequence files and produces from each one a quality control report consisting of a number of different modules, each one of which will help to identify a different potential type of problem in your data.\nIf no files to process are specified on the command line then the program will start as an interactive graphical application.  If files are provided on the command line then the program will run with no user interaction required.  In this mode it is suitable for inclusion into a standardised analysis pipeline.\n  \nPlease visit https://www.bioinformatics.babraham.ac.uk/projects/fastqc/ for full documentation.\n  \n",
            "label": "FastQC - A high throughtput sequence analyses QC.",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fastqc:0.11.7--4"
                }
            ],
            "id": "#FastQC-v0.11.7.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew",
            "outputs": [
                {
                    "id": "#FastQC-v0.11.7.cwl/zipped_report",
                    "label": "Zipped output report",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_fastqc.zip"
                    }
                },
                {
                    "id": "#FastQC-v0.11.7.cwl/html_report",
                    "label": "HTML output report",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_fastqc.html"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "transrate"
            ],
            "inputs": [
                {
                    "id": "#Transrate-V1.0.3.cwl/in_fasta",
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--assembly=",
                        "separate": false
                    },
                    "label": "Assembly FASTA file",
                    "doc": "Assembly file(s) in FASTA format, comma-separated\n"
                },
                {
                    "id": "#Transrate-V1.0.3.cwl/left_fastq",
                    "format": "http://edamontology.org/format_1930",
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--left=",
                        "separate": false
                    },
                    "label": "Left reads FASTQ file(s)",
                    "doc": "Left reads file(s) in FASTQ format, comma-separated\n"
                },
                {
                    "id": "#Transrate-V1.0.3.cwl/right_fastq",
                    "format": "http://edamontology.org/format_1930",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--right=",
                        "separate": false
                    },
                    "label": "Right reads FASTQ file(s)",
                    "doc": "Right reads file(s) in FASTQ format, comma-separated\n"
                },
                {
                    "id": "#Transrate-V1.0.3.cwl/n_threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--threads=",
                        "separate": false
                    },
                    "label": "Number of threads allocated",
                    "doc": "Number of threads to use (default: 8)\n"
                },
                {
                    "id": "#Transrate-V1.0.3.cwl/log_level",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--loglevel=",
                        "separate": false
                    },
                    "label": "LOG file(s)",
                    "doc": "Log level. One of [error, info, warn, debug] (default: info)\n"
                }
            ],
            "outputs": [
                {
                    "id": "#Transrate-V1.0.3.cwl/transrate_output_dir",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "."
                    }
                }
            ],
            "doc": "Analyse a de-novo transcriptome assembly using three kinds of metrics: 1. sequence based (if --assembly is given) 2. read mapping based (if --left and --right are given) 3. reference based (if --reference is given)\nDocumentation at http://hibberdlab.com/transrate\n      \n",
            "label": "Transrate - A de-novo transcriptome assembly evaluation facility.",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--output=",
                    "separate": false,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "1.0.3"
                            ],
                            "package": "transrate"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "arnaudmeng/transrate:1.0.3"
                }
            ],
            "id": "#Transrate-V1.0.3.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "0.36--6"
                            ],
                            "package": "trimmomatic"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/trimmomatic:0.36--6"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 10240,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping",
                            "fields": [
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/adapters",
                                    "type": "File",
                                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/seedMismatches",
                                    "type": "int",
                                    "doc": "specifies the maximum mismatch count which will still allow a full match\nto be performed\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/palindromeClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between the two 'adapter ligated' reads\nmust be for PE palindrome read alignment.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/simpleClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between any adapter etc. sequence must\nbe against a read\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/minAdapterLength",
                                    "type": [
                                        "null",
                                        "int"
                                    ],
                                    "doc": "In addition to the alignment score, palindrome mode can verify that a\nminimum length of adapter has been detected. If unspecified, this\ndefaults to 8 bases, for historical reasons. However, since palindrome\nmode has a very low false positive rate, this can be safely reduced, even\ndown to 1, to allow shorter adapter fragments to be removed.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/keepBothReads",
                                    "type": "boolean",
                                    "doc": "After read-though has been detected by palindrome mode, and the adapter\nsequence removed, the reverse read contains the same sequence information\nas the forward read, albeit in reverse complement. For this reason, the\ndefault behaviour is to entirely drop the reverse read. By specifying\n\"true\" for this parameter, the reverse read will also be retained, which\nmay be useful e.g. if the downstream tools cannot handle a combination of\npaired and unpaired reads."
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-max_info.yaml/maxinfo",
                            "fields": [
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/targetLength",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/strictness",
                                    "type": "int"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "label": "minimum average quality required",
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#Trimmomatic-v0.36.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "label": "read cropping",
                    "doc": "Removes bases regardless of quality from the end of the read, so that the read has maximally the specified length after this step has been performed. Steps performed after CROP might of course further shorten the read. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36.cwl/crop"
                },
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "read -end mode format",
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#Trimmomatic-v0.36.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "label": "read head trimming",
                    "doc": "Removes the specified number of bases, regardless of quality, from the beginning of the read. The numbser specified is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-illumina_clipping.yaml/illuminaClipping"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if ( self ) {\n     return \"ILLUMINACLIP:\" + inputs.illuminaClip.adapters.path + \":\"\n       + self.seedMismatches + \":\" + self.palindromeClipThreshold + \":\"\n       + self.simpleClipThreshold + \":\" + self.minAdapterLength + \":\"\n       + self.keepBothReads;\n   } else {\n     return self;\n   }\n }\n",
                        "position": 11
                    },
                    "label": "sequencing adaptater removing",
                    "doc": "Cut adapter and other illumina-specific sequences from the read.\n",
                    "id": "#Trimmomatic-v0.36.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#Trimmomatic-v0.36.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "label": "read tail trimming",
                    "doc": "Remove low quality bases from the beginning. As long as a base has a value below this threshold the base is removed and the next base will be investigated.\n",
                    "id": "#Trimmomatic-v0.36.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-max_info.yaml/maxinfo"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"MAXINFO:\" + self.targetLength + \":\" + self.strictness;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "label": "maxinfo: read score quality filtering",
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining longer reads against the costs of retaining bases with errors. <targetLength>: This specifies the read length which is likely to allow the location of the read within the target sequence to be determined. <strictness>: This value, which should be set between 0 and 1, specifies the balance between preserving as much read length as possible vs. removal of incorrect bases. A low value of this parameter (<0.2) favours longer reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#Trimmomatic-v0.36.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "label": "minimum length read filter",
                    "doc": "This module removes reads that fall below the specified minimal length. If required, it should normally be after all other processing steps. Reads removed by this step will be counted and included in the \"dropped reads\" count presented in the trimmomatic summary.\n",
                    "id": "#Trimmomatic-v0.36.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-phred.yaml/phred"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "label": "quality score format",
                    "doc": "Either PHRED \"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#Trimmomatic-v0.36.cwl/phred"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "label": "FASTQ read file 1",
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)\n",
                    "id": "#Trimmomatic-v0.36.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "label": "FASTQ read file 2",
                    "doc": "FASTQ file of R2 reads in Paired End mode\n",
                    "id": "#Trimmomatic-v0.36.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-sliding_window.yaml/slidingWindow"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"SLIDINGWINDOW:\" + self.windowSize + \":\"\n       + self.requiredQuality;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "label": "read filtering sliding window",
                    "doc": "Perform a sliding window trimming, cutting once the average quality within the window falls below a threshold. By considering multiple bases, a single poor quality base will not cause the removal of high quality data later in the read. <windowSize> specifies the number of bases to average across <requiredQuality> specifies the average quality required\n",
                    "id": "#Trimmomatic-v0.36.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "label": "quality score conversion to phred33",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.\n",
                    "id": "#Trimmomatic-v0.36.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "label": "quality score conversion to phred64",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.\n",
                    "id": "#Trimmomatic-v0.36.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "label": "read tail quality filtering",
                    "doc": "Remove low quality bases from the end. As long as a base has a value below this threshold the base is removed and the next base (which as trimmomatic is starting from the 3' prime end would be base preceding the just removed base) will be investigated. This approach can be used removing the special Illumina \"low quality segment\" regions (which are marked with quality score of 2), but we recommend Sliding Window or MaxInfo instead\n",
                    "id": "#Trimmomatic-v0.36.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Log file",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#Trimmomatic-v0.36.cwl/log_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.fastq"
                    },
                    "id": "#Trimmomatic-v0.36.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.unpaired.fastq"
                    },
                    "id": "#Trimmomatic-v0.36.cwl/reads1_trimmed_unpaired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#Trimmomatic-v0.36.cwl/reads2_trimmed_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#Trimmomatic-v0.36.cwl/reads2_trimmed_unpaired"
                }
            ],
            "baseCommand": [
                "trimmomatic"
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 4,
                    "prefix": "-threads"
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed.fastq",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads1.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 10
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop Illumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem depending on the library preparation and downstream application. There are two major modes of the program: Paired end mode and Single end mode. The paired end mode will maintain correspondence of read pairs and also use the additional information contained in paired reads to better find adapter or PCR primer fragments introduced by the library preparation process. Trimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores, depending on the Illumina pipeline used).\n",
            "label": "Trimmomatic - A flexible read trimming tool for Illumina NGS data",
            "id": "#Trimmomatic-v0.36.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trinity-ss_lib_type.yaml/trinity_ss_lib_type",
                            "symbols": [
                                "#trinity-ss_lib_type.yaml/trinity_ss_lib_type/FR",
                                "#trinity-ss_lib_type.yaml/trinity_ss_lib_type/RF",
                                "#trinity-ss_lib_type.yaml/trinity_ss_lib_type/F",
                                "#trinity-ss_lib_type.yaml/trinity_ss_lib_type/R"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trinity-seq_type.yaml/seq_type",
                            "symbols": [
                                "#trinity-seq_type.yaml/seq_type/fa",
                                "#trinity-seq_type.yaml/seq_type/fq"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "baseCommand": [
                "/usr/local/bin/trinityrnaseq/Trinity",
                "--full_cleanup"
            ],
            "inputs": [
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/trinity_seq_type",
                    "type": "string",
                    "default": "fa",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seqType"
                    },
                    "label": "read file(s) format",
                    "doc": "type of reads: (fa or fq)\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/trinity_max_mem",
                    "type": "string",
                    "default": "20G",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--max_memory"
                    },
                    "label": "maximum memory allocated",
                    "doc": "Suggested max memory to use by Trinity where limiting can be enabled. (jellyfish, sorting, etc) provided in Gb of RAM, ie. --max_memory 10G\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/left_reads",
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--left",
                        "itemSeparator": ","
                    },
                    "label": "left read(s)",
                    "doc": "left reads, one or more file names (separated by commas, no spaces)\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/right_reads",
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--right",
                        "itemSeparator": ","
                    },
                    "label": "right read(s)",
                    "doc": "right reads, one or more file names (separated by commas, no spaces)\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/trinity_ss_lib_type",
                    "type": "string",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--SS_lib_type"
                    },
                    "label": "Strand-specific RNA-Seq read orientation",
                    "doc": "Strand-specific RNA-Seq read orientation. if paired: RF or FR, if single: F or R. (dUTP method = RF). See web documentation\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/trinity_cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--CPU"
                    },
                    "label": "number of CPUs allocated",
                    "doc": "number of CPUs to use by Trinity\n"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/no_normalize_reads",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--no_normalize_reads"
                    },
                    "label": "Do *not* run in silico normalization of reads. default: normalize reads"
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/normalize_by_read_set",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--normalize_by_read_set"
                    },
                    "label": "Run normalization separate for each pair of fastq files"
                }
            ],
            "outputs": [
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/assembly_dir",
                    "label": "Assembly directory containing assembly results",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "."
                    }
                },
                {
                    "id": "#Trinity-V2.6.5.paired-end.cwl/assembled_contigs",
                    "label": "Generated contigs",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*fasta"
                    }
                }
            ],
            "doc": "Trinity, developed at the Broad Institute and the Hebrew University of Jerusalem,  represents a novel method for the efficient and robust de novo reconstruction  of transcriptomes from RNA-seq data.  Trinity combines three independent software modules: Inchworm, Chrysalis, and  Butterfly, applied sequentially to process large volumes of RNA-seq reads.\nDocumentation at https://github.com/trinityrnaseq/trinityrnaseq/wiki\n",
            "label": "Trinity assembles transcript sequences from Illumina RNA-Seq data.",
            "arguments": [
                {
                    "prefix": "--output",
                    "valueFrom": "$(runtime.outdir)/trinity_out_dir/"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.6.5"
                            ],
                            "package": "Trinity"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "trinityrnaseq/trinityrnaseq:2.6.5"
                }
            ],
            "id": "#Trinity-V2.6.5.paired-end.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "label": "Transcriptome assembly workflow (paired-end version)",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        },
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "label": "read -end mode format",
                    "doc": "Read -end mode format to be specify to Trimmomatic\n",
                    "id": "#main/end_mode"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "Paired-end read file 1",
                    "doc": "Read file 1 in FASTQ format \n",
                    "id": "#main/forward_reads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "label": "FASTQ read file(s)",
                    "doc": "FASTQ file of reverse reads in Paired End mode\n",
                    "id": "#main/read_files"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "Paired-end read file 2",
                    "doc": "Read file 2 in FASTQ format\n",
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "#trimmomatic-phred.yaml/phred",
                    "label": "quality score format",
                    "default": "33",
                    "doc": "Either PHRED \"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#main/trimmomatic_phred"
                },
                {
                    "type": "#trimmomatic-sliding_window.yaml/slidingWindow",
                    "label": "read filtering sliding window",
                    "default": {
                        "windowSize": 4,
                        "requiredQuality": 15
                    },
                    "doc": "Perform a sliding window trimming, cutting once the average quality within the window falls below a threshold. By considering multiple bases, a single poor quality base will not cause the removal of high quality data later in the read. <windowSize> specifies the number of bases to average across <requiredQuality> specifies the average quality required\n",
                    "id": "#main/trimmomatic_slidingWindow"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "number of CPUs allocated",
                    "doc": "number of CPUs to use, default: 2\n",
                    "id": "#main/trinity_cpu"
                },
                {
                    "type": "string",
                    "label": "maximum memory allocated to Trinity",
                    "doc": "Suggested max memory to use by Trinity where limiting can be enabled. (jellyfish, sorting, etc) provided in Gb of RAM, ie. --max_memory 10G\n",
                    "id": "#main/trinity_max_mem"
                },
                {
                    "type": "string",
                    "label": "read file(s) format",
                    "doc": "type of reads: (fa or fq)\n",
                    "id": "#main/trinity_seq_type"
                },
                {
                    "type": "string",
                    "label": "Strand-specific RNA-Seq read orientation",
                    "doc": "Strand-specific RNA-Seq read orientation. if paired: RF or FR, if single: F or R. (dUTP method = RF). See web documentation\n",
                    "id": "#main/trinity_ss_lib_type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#main/run_assembly/assembled_contigs",
                    "id": "#main/assembled_contigs"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/run_assembly/assembly_dir",
                    "id": "#main/assembly_output_dir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_2331",
                    "outputSource": "#main/generate_filtered_stats/html_report",
                    "id": "#main/filtered_html_report"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/generate_filtered_stats/zipped_report",
                    "id": "#main/filtered_qc_report"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/filter_reads/reads1_trimmed",
                    "id": "#main/forward_reads_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/filter_reads/reads1_trimmed_unpaired",
                    "id": "#main/forward_reads_unpaired"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_2331",
                    "outputSource": "#main/generate_raw_stats/html_report",
                    "id": "#main/raw_html_report"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/generate_raw_stats/zipped_report",
                    "id": "#main/raw_qc_report"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/filter_reads/reads2_trimmed_paired",
                    "id": "#main/reverse_reads_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/filter_reads/reads2_trimmed_unpaired",
                    "id": "#main/reverse_reads_unpaired"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/evaluate_contigs/transrate_output_dir",
                    "id": "#main/transrate_output_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/filter_reads/log_file",
                    "id": "#main/trimmomatic_log_file"
                }
            ],
            "steps": [
                {
                    "label": "Evaluates the contig quality.",
                    "doc": "Provide the assembled contigs (FASTA file)\n",
                    "run": "#Transrate-V1.0.3.cwl",
                    "in": [
                        {
                            "source": "#main/run_assembly/assembled_contigs",
                            "id": "#main/evaluate_contigs/in_fasta"
                        },
                        {
                            "source": "#main/filter_reads/reads1_trimmed",
                            "id": "#main/evaluate_contigs/left_fastq"
                        },
                        {
                            "source": "#main/filter_reads/reads2_trimmed_paired",
                            "id": "#main/evaluate_contigs/right_fastq"
                        }
                    ],
                    "out": [
                        "#main/evaluate_contigs/transrate_output_dir"
                    ],
                    "id": "#main/evaluate_contigs"
                },
                {
                    "label": "Filtering and trimmming read file(s)",
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#Trimmomatic-v0.36.cwl",
                    "in": [
                        {
                            "source": "#main/end_mode",
                            "id": "#main/filter_reads/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#main/filter_reads/leading"
                        },
                        {
                            "default": 100,
                            "id": "#main/filter_reads/minlen"
                        },
                        {
                            "source": "#main/trimmomatic_phred",
                            "id": "#main/filter_reads/phred"
                        },
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/filter_reads/reads1"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/filter_reads/reads2"
                        },
                        {
                            "source": "#main/trimmomatic_slidingWindow",
                            "id": "#main/filter_reads/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#main/filter_reads/trailing"
                        }
                    ],
                    "out": [
                        "#main/filter_reads/log_file",
                        "#main/filter_reads/reads1_trimmed",
                        "#main/filter_reads/reads1_trimmed_unpaired",
                        "#main/filter_reads/reads2_trimmed_paired",
                        "#main/filter_reads/reads2_trimmed_unpaired"
                    ],
                    "id": "#main/filter_reads"
                },
                {
                    "label": "Generates a QC for the filtered read file(s).",
                    "doc": "Provide filtered/trimmed read file(s)\n",
                    "run": "#FastQC-v0.11.7.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/filter_reads/reads1_trimmed"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/generate_filtered_stats/in_fastq"
                        }
                    ],
                    "out": [
                        "#main/generate_filtered_stats/zipped_report",
                        "#main/generate_filtered_stats/html_report"
                    ],
                    "id": "#main/generate_filtered_stats"
                },
                {
                    "label": "Generates a QC for the provided read file(s).",
                    "doc": "Provide reverse and forward read files for paired-end (PE)\nor a single read file for single-end (SE).\n",
                    "run": "#FastQC-v0.11.7.cwl",
                    "in": [
                        {
                            "source": "#main/read_files",
                            "id": "#main/generate_raw_stats/in_fastq"
                        }
                    ],
                    "out": [
                        "#main/generate_raw_stats/zipped_report",
                        "#main/generate_raw_stats/html_report"
                    ],
                    "id": "#main/generate_raw_stats"
                },
                {
                    "label": "Runs the actual assembly",
                    "doc": "provide filtered/trimmed read file(s)\n",
                    "run": "#Trinity-V2.6.5.paired-end.cwl",
                    "in": [
                        {
                            "source": "#main/filter_reads/reads1_trimmed",
                            "id": "#main/run_assembly/left_reads"
                        },
                        {
                            "source": "#main/filter_reads/reads2_trimmed_paired",
                            "id": "#main/run_assembly/right_reads"
                        },
                        {
                            "source": "#main/trinity_cpu",
                            "id": "#main/run_assembly/trinity_cpu"
                        },
                        {
                            "source": "#main/trinity_max_mem",
                            "id": "#main/run_assembly/trinity_max_mem"
                        },
                        {
                            "source": "#main/trinity_seq_type",
                            "id": "#main/run_assembly/trinity_seq_type"
                        },
                        {
                            "source": "#main/trinity_ss_lib_type",
                            "id": "#main/run_assembly/trinity_ss_lib_type"
                        }
                    ],
                    "out": [
                        "#main/run_assembly/assembly_dir",
                        "#main/run_assembly/assembled_contigs"
                    ],
                    "id": "#main/run_assembly"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2019",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.20.owl",
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
